Blob Blame History Raw
commit bbfe25a3d9942714ce5c5c6a056232751ac798ea
Author: Pino Toscano <ptoscano@redhat.com>
Date:   Thu Nov 16 15:18:25 2017 +0100

    Disable VNC console on s390x
    
    There is no PCI support there, which is used when enabling VNC.
    
    Signed-off-by: Pino Toscano <ptoscano@redhat.com>

diff --git oz/Guest.py oz/Guest.py
index 16a8b5a..85580d4 100644
--- oz/Guest.py
+++ oz/Guest.py
@@ -484,8 +484,8 @@ class Guest(object):
         # devices
         devices = oz.ozutil.lxml_subelement(domain, "devices")
         # graphics
-        if not self.tdl.arch in ["aarch64", "armv7l"]:
-            # qemu for arm/aarch64 does not support a graphical console - amazingly
+        if not self.tdl.arch in ["aarch64", "armv7l", "s390x"]:
+            # qemu for arm/aarch64/s390x does not support a graphical console - amazingly
             oz.ozutil.lxml_subelement(devices, "graphics", None, {'port':'-1', 'type':'vnc'})
         # network
         interface = oz.ozutil.lxml_subelement(devices, "interface", None, {'type':'bridge'})